@@ -10,7 +10,7 @@ require HTML::DOM::Element;
 require HTML::DOM::NodeList::Magic;
 #require HTML::DOM::Collection::Elements;
 
-our $VERSION = '0.030';
+our $VERSION = '0.031';
 our @ISA = qw'HTML::DOM::Element';
 
 use overload fallback => 1,
@@ -34,7 +34,11 @@ sub elements {
 		my $collection = HTML::DOM::Collection::Elements->new(
 		my $list = HTML::DOM::NodeList::Magic->new(
 		   sub {
-		     grep($elem_elems{tag $_}, $self->descendants),
+		     no warnings 'uninitialized';
+		     grep(
+		      $elem_elems{tag $_} && attr $_ 'type', ne 'image',
+		      $self->descendants
+		     ),
 		     @{ $self->{_HTML_DOM_mg_elems}||[] }
 		    } 
 		));
@@ -110,7 +114,13 @@ sub trigger_event {
 sub inputs {
 	my @ret;
 	my %pos;
-	for(shift->elements) {
+	my $self = shift;
+	# This used to use ‘$self->elements’, but ->elements no longer
+	# includes image buttons.
+	for(
+	 grep($elem_elems{tag $_}, $self->descendants),
+	 @{ $self->{_HTML_DOM_mg_elems}||[] }
+	) {
 	  next if (my $tag = tag $_) eq 'button'; # HTML::Form doesn't deal
 	                                          # with <button>s.
 	  no warnings 'uninitialized'; # for 5.11.0
@@ -396,7 +406,7 @@ package HTML::DOM::NodeList::Radio; # solely for HTML::Form compatibility
 use Carp 'croak';
 require HTML::DOM::NodeList;
 
-our $VERSION = '0.030';
+our $VERSION = '0.031';
 our @ISA = qw'HTML::DOM::NodeList';
 
 sub type { 'radio' }
@@ -468,7 +478,7 @@ use warnings;
 
 use Scalar::Util 'weaken';
 
-our $VERSION = '0.030';
+our $VERSION = '0.031';
 
 require HTML::DOM::Collection;
 our @ISA = 'HTML::DOM::Collection';
@@ -645,7 +655,7 @@ L<HTML::Form>
 # ------- HTMLSelectElement interface ---------- #
 
 package HTML::DOM::Element::Select;
-our $VERSION = '0.030';
+our $VERSION = '0.031';
 our @ISA = 'HTML::DOM::Element';
 
 use overload fallback=>1, '@{}' => sub { shift->options };
@@ -739,7 +749,7 @@ package HTML::DOM::Collection::Options;
 use strict;
 use warnings;
 
-our $VERSION = '0.030';
+our $VERSION = '0.031';
 
 use Carp 'croak';
 use constant::lexical sel => 5; # must not conflict with super
@@ -815,7 +825,7 @@ sub length { # override
 # ------- HTMLOptGroupElement interface ---------- #
 
 package HTML::DOM::Element::OptGroup;
-our $VERSION = '0.030';
+our $VERSION = '0.031';
 our @ISA = 'HTML::DOM::Element';
 
 sub label  { shift->_attr( label => @_) }
@@ -825,7 +835,7 @@ sub label  { shift->_attr( label => @_) }
 # ------- HTMLOptionElement interface ---------- #
 
 package HTML::DOM::Element::Option;
-our $VERSION = '0.030';
+our $VERSION = '0.031';
 our @ISA = qw'HTML::DOM::Element';
 
 use Carp 'croak';
@@ -936,7 +946,7 @@ sub _reset { delete shift->{_HTML_DOM_sel} }
 # ------- HTMLInputElement interface ---------- #
 
 package HTML::DOM::Element::Input;
-our $VERSION = '0.030';
+our $VERSION = '0.031';
 our @ISA = qw'HTML::DOM::Element';
 
 use Carp 'croak';
@@ -1145,7 +1155,7 @@ sub content {
 # ------- HTMLTextAreaElement interface ---------- #
 
 package HTML::DOM::Element::TextArea;
-our $VERSION = '0.030';
+our $VERSION = '0.031';
 our @ISA = qw'HTML::DOM::Element';
 
 sub defaultValue { # same as HTML::DOM::Element::Title::text
@@ -1193,7 +1203,7 @@ sub _reset {
 # ------- HTMLButtonElement interface ---------- #
 
 package HTML::DOM::Element::Button;
-our $VERSION = '0.030';
+our $VERSION = '0.031';
 our @ISA = qw'HTML::DOM::Element';
 
 *form = \&HTML::DOM::Element::Select::form;
@@ -1208,7 +1218,7 @@ sub value      { shift->attr( value       => @_) }
 # ------- HTMLLabelElement interface ---------- #
 
 package HTML::DOM::Element::Label;
-our $VERSION = '0.030';
+our $VERSION = '0.031';
 our @ISA = qw'HTML::DOM::Element';
 
 *form = \&HTML::DOM::Element::Select::form;
@@ -1218,7 +1228,7 @@ sub htmlFor { shift->_attr( for       => @_) }
 # ------- HTMLFieldSetElement interface ---------- #
 
 package HTML::DOM::Element::FieldSet;
-our $VERSION = '0.030';
+our $VERSION = '0.031';
 our @ISA = qw'HTML::DOM::Element';
 
 *form = \&HTML::DOM::Element::Select::form;
@@ -1226,7 +1236,7 @@ our @ISA = qw'HTML::DOM::Element';
 # ------- HTMLLegendElement interface ---------- #
 
 package HTML::DOM::Element::Legend;
-our $VERSION = '0.030';
+our $VERSION = '0.031';
 our @ISA = qw'HTML::DOM::Element';
 
 *form = \&HTML::DOM::Element::Select::form;
